@@ -219,10 +219,10 @@ class BigQueryDeleteDataTransferConfigOperator(GoogleCloudBaseOperator):
 
 class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperator):
     """
-    Start manual transfer runs to be executed now with schedule_time equal
-    to current time. The transfer runs can be created for a time range where
-    the run_time is between start_time (inclusive) and end_time
-    (exclusive), or for a specific run_time.
+    Start manual transfer runs to be executed now with schedule_time equal to current time.
+
+    The transfer runs can be created for a time range where the run_time is between
+    start_time (inclusive) and end_time (exclusive), or for a specific run_time.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
