@@ -65,6 +65,8 @@ class DataformCreateCompilationResultOperator(GoogleCloudBaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
+    template_fields = ("repository_id", "impersonation_chain")
+
     def __init__(
         self,
         project_id: str,
@@ -1029,8 +1031,9 @@ class DataformRemoveDirectoryOperator(GoogleCloudBaseOperator):
 
 
 class DataformInstallNpmPackagesOperator(GoogleCloudBaseOperator):
-    """
-    Installs npm dependencies in the provided workspace. Requires "package.json" to be created in workspace.
+    """Install NPM dependencies in the provided workspace.
+
+    Requires "package.json" to be created in the workspace.
 
     :param project_id: Required. The ID of the Google Cloud project where workspace located.
     :param region: Required. The ID of the Google Cloud region where workspace located.
